==> qtjambi-xmlpatterns-5.15.7-sources.jar: io/qt/xmlpatterns/QAbstractMessageHandler.java <==
package io.qt.xmlpatterns;


/**
 * <p>Callback interface for handling messages</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qabstractmessagehandler.html">QAbstractMessageHandler</a></p>
 */
public abstract class QAbstractMessageHandler extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAbstractMessageHandler.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QAbstractMessageHandler {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        protected void handleMessage(io.qt.core.QtMsgType type, java.lang.String description, io.qt.core.QUrl identifier, io.qt.xmlpatterns.QSourceLocation sourceLocation){
            handleMessage_native_QtMsgType_cref_QString_cref_QUrl_cref_QSourceLocation(QtJambi_LibraryUtilities.internal.nativeId(this), type.value(), description, QtJambi_LibraryUtilities.internal.checkedNativeId(identifier), QtJambi_LibraryUtilities.internal.checkedNativeId(sourceLocation));
        }
        @io.qt.QtUninvokable
        private native void handleMessage_native_QtMsgType_cref_QString_cref_QUrl_cref_QSourceLocation(long __this__nativeId, int type, java.lang.String description, long identifier, long sourceLocation);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QAbstractMessageHandler(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QAbstractMessageHandler() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractmessagehandler.html#QAbstractMessageHandler">QAbstractMessageHandler::QAbstractMessageHandler(QObject*)</a></p>
     */
    public QAbstractMessageHandler(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAbstractMessageHandler instance, io.qt.core.QObject parent);
    
    /**
     * <p>Overloaded function for {@link #message(io.qt.core.QtMsgType, java.lang.String, io.qt.core.QUrl, io.qt.xmlpatterns.QSourceLocation)}
     *  with <code>sourceLocation = new io.qt.xmlpatterns.QSourceLocation()</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void message(io.qt.core.QtMsgType type, java.lang.String description, io.qt.core.QUrl identifier) {
        message(type, description, identifier, new io.qt.xmlpatterns.QSourceLocation());
    }
    
    /**
     * <p>Overloaded function for {@link #message(io.qt.core.QtMsgType, java.lang.String, io.qt.core.QUrl, io.qt.xmlpatterns.QSourceLocation)}</p>
     * <p>with: </p><ul>
     * <li><code>identifier = new io.qt.core.QUrl()</code></li>
     * <li><code>sourceLocation = new io.qt.xmlpatterns.QSourceLocation()</code></li>
     * </ul>
     */
    @io.qt.QtUninvokable
    public final void message(io.qt.core.QtMsgType type, java.lang.String description) {
        message(type, description, new io.qt.core.QUrl(), new io.qt.xmlpatterns.QSourceLocation());
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractmessagehandler.html#message">QAbstractMessageHandler::message(QtMsgType,QString,QUrl,QSourceLocation)</a></p>
     */
    @io.qt.QtUninvokable
    public final void message(io.qt.core.QtMsgType type, java.lang.String description, io.qt.core.QUrl identifier, io.qt.xmlpatterns.QSourceLocation sourceLocation){
        message_native_QtMsgType_cref_QString_cref_QUrl_cref_QSourceLocation(QtJambi_LibraryUtilities.internal.nativeId(this), type.value(), description, QtJambi_LibraryUtilities.internal.checkedNativeId(identifier), QtJambi_LibraryUtilities.internal.checkedNativeId(sourceLocation));
    }
    
    @io.qt.QtUninvokable
    private native void message_native_QtMsgType_cref_QString_cref_QUrl_cref_QSourceLocation(long __this__nativeId, int type, java.lang.String description, long identifier, long sourceLocation);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractmessagehandler.html#handleMessage">QAbstractMessageHandler::handleMessage(QtMsgType,QString,QUrl,QSourceLocation)</a></p>
     */
    @io.qt.QtUninvokable
    protected abstract void handleMessage(io.qt.core.QtMsgType type, java.lang.String description, io.qt.core.QUrl identifier, io.qt.xmlpatterns.QSourceLocation sourceLocation);
    
    @io.qt.QtUninvokable
    private native void handleMessage_native_QtMsgType_cref_QString_cref_QUrl_cref_QSourceLocation(long __this__nativeId, int type, java.lang.String description, long identifier, long sourceLocation);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAbstractMessageHandler(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAbstractMessageHandler(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAbstractMessageHandler instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-xmlpatterns-5.15.12-sources.jar: io/qt/xmlpatterns/QAbstractMessageHandler.java <==
package io.qt.xmlpatterns;


/**
 * <p>Callback interface for handling messages</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qabstractmessagehandler.html">QAbstractMessageHandler</a></p>
 */
public abstract class QAbstractMessageHandler extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAbstractMessageHandler.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QAbstractMessageHandler {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        protected void handleMessage(io.qt.core.QtMsgType type, java.lang.String description, io.qt.core.QUrl identifier, io.qt.xmlpatterns.QSourceLocation sourceLocation){
            handleMessage_native_QtMsgType_cref_QString_cref_QUrl_cref_QSourceLocation(QtJambi_LibraryUtilities.internal.nativeId(this), type.value(), description, QtJambi_LibraryUtilities.internal.checkedNativeId(identifier), QtJambi_LibraryUtilities.internal.checkedNativeId(sourceLocation));
        }
        @io.qt.QtUninvokable
        private native void handleMessage_native_QtMsgType_cref_QString_cref_QUrl_cref_QSourceLocation(long __this__nativeId, int type, java.lang.String description, long identifier, long sourceLocation);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QAbstractMessageHandler(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QAbstractMessageHandler() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractmessagehandler.html#QAbstractMessageHandler">QAbstractMessageHandler::QAbstractMessageHandler(QObject*)</a></p>
     */
    public QAbstractMessageHandler(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAbstractMessageHandler instance, io.qt.core.QObject parent);
    
    /**
     * <p>Overloaded function for {@link #message(io.qt.core.QtMsgType, java.lang.String, io.qt.core.QUrl, io.qt.xmlpatterns.QSourceLocation)}
     *  with <code>sourceLocation = new io.qt.xmlpatterns.QSourceLocation()</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void message(io.qt.core.QtMsgType type, java.lang.String description, io.qt.core.QUrl identifier) {
        message(type, description, identifier, new io.qt.xmlpatterns.QSourceLocation());
    }
    
    /**
     * <p>Overloaded function for {@link #message(io.qt.core.QtMsgType, java.lang.String, io.qt.core.QUrl, io.qt.xmlpatterns.QSourceLocation)}</p>
     * <p>with: </p><ul>
     * <li><code>identifier = new io.qt.core.QUrl()</code></li>
     * <li><code>sourceLocation = new io.qt.xmlpatterns.QSourceLocation()</code></li>
     * </ul>
     */
    @io.qt.QtUninvokable
    public final void message(io.qt.core.QtMsgType type, java.lang.String description) {
        message(type, description, new io.qt.core.QUrl(), new io.qt.xmlpatterns.QSourceLocation());
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractmessagehandler.html#message">QAbstractMessageHandler::message(QtMsgType,QString,QUrl,QSourceLocation)</a></p>
     */
    @io.qt.QtUninvokable
    public final void message(io.qt.core.QtMsgType type, java.lang.String description, io.qt.core.QUrl identifier, io.qt.xmlpatterns.QSourceLocation sourceLocation){
        message_native_QtMsgType_cref_QString_cref_QUrl_cref_QSourceLocation(QtJambi_LibraryUtilities.internal.nativeId(this), type.value(), description, QtJambi_LibraryUtilities.internal.checkedNativeId(identifier), QtJambi_LibraryUtilities.internal.checkedNativeId(sourceLocation));
    }
    
    @io.qt.QtUninvokable
    private native void message_native_QtMsgType_cref_QString_cref_QUrl_cref_QSourceLocation(long __this__nativeId, int type, java.lang.String description, long identifier, long sourceLocation);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractmessagehandler.html#handleMessage">QAbstractMessageHandler::handleMessage(QtMsgType,QString,QUrl,QSourceLocation)</a></p>
     */
    @io.qt.QtUninvokable
    protected abstract void handleMessage(io.qt.core.QtMsgType type, java.lang.String description, io.qt.core.QUrl identifier, io.qt.xmlpatterns.QSourceLocation sourceLocation);
    
    @io.qt.QtUninvokable
    private native void handleMessage_native_QtMsgType_cref_QString_cref_QUrl_cref_QSourceLocation(long __this__nativeId, int type, java.lang.String description, long identifier, long sourceLocation);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAbstractMessageHandler(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAbstractMessageHandler(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAbstractMessageHandler instance, QDeclarativeConstructor constructor);
    
}
